import{j as a}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{j as f,h as j,i as D,B as l,o as z,s as g,t as N}from"./polymorphic-factory-EW0USS3V.js";var n={root:"m_3eebeb36",label:"m_9e365f20"};const P={orientation:"horizontal"},R=z((o,{color:e,variant:s,size:r})=>({root:{"--divider-color":e?N(e,o):void 0,"--divider-border-style":s,"--divider-size":g(r,"divider-size")}})),d=f((o,e)=>{const s=j("Divider",P,o),{classNames:r,className:m,style:c,styles:p,unstyled:v,vars:b,color:S,orientation:y,label:t,labelPosition:h,mod:u,...x}=s,i=D({name:"Divider",classes:n,props:s,className:m,style:c,classNames:r,styles:p,unstyled:v,vars:b,varsResolver:R});return a.jsx(l,{ref:e,mod:[{orientation:y,"with-label":!!t},u],...i("root"),...x,role:"separator",children:t&&a.jsx(l,{component:"span",mod:{position:h},...i("label"),children:t})})});d.classes=n;d.displayName="@mantine/core/Divider";export{d as D};
