import{j as s}from"./jsx-runtime-D_zvdyIk.js";import{a as r}from"./chunk-QMGIS6GS-CBZUm-7V.js";function i(o){const e=r.createContext(null);return[({children:t,value:n})=>s.jsx(e.Provider,{value:n,children:t}),()=>{const t=r.useContext(e);if(t===null)throw new Error(o);return t}]}export{i as c};
