._title_tghqc_1{font-family:Outfit,var(--mantine-font-family);font-weight:500}._subtitle_tghqc_6{color:var(--mantine-color-dimmed);font-size:var(--mantine-font-size-sm);text-align:center;margin-top:5px}
