import{j as S}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{p as j,h as N,i as R,B as _,o as z,t as B,H as F,J as H,v as P}from"./polymorphic-factory-EW0USS3V.js";var n={root:"m_b6d8b162"};function C(t){if(t==="start")return"start";if(t==="end"||t)return"end"}const E={inherit:!1},G=z((t,{variant:r,lineClamp:e,gradient:o,size:s,color:a})=>({root:{"--text-fz":P(s),"--text-lh":H(s),"--text-gradient":r==="gradient"?F(o,t):void 0,"--text-line-clamp":typeof e=="number"?e.toString():void 0,"--text-color":a?B(a,t):void 0}})),i=j((t,r)=>{const e=N("Text",E,t),{lineClamp:o,truncate:s,inline:a,inherit:l,gradient:J,span:c,__staticSelector:p,vars:d,className:m,style:u,classNames:x,styles:f,unstyled:g,variant:v,mod:y,size:h,...T}=e,b=R({name:["Text",p],props:e,classes:n,className:m,style:u,classNames:x,styles:f,unstyled:g,vars:d,varsResolver:G});return S.jsx(_,{...b("root",{focusable:!0}),ref:r,component:c?"span":"p",variant:v,mod:[{"data-truncate":C(s),"data-line-clamp":typeof o=="number","data-inline":a,"data-inherit":l},y],size:h,...T})});i.classes=n;i.displayName="@mantine/core/Text";export{i as T};
