import{j as u}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{j as f,h as S,i as j,o as k,B as v,m as x}from"./polymorphic-factory-EW0USS3V.js";var o={root:"m_6d731127"};const d={gap:"md",align:"stretch",justify:"flex-start"},h=k((e,{gap:t,align:s,justify:a})=>({root:{"--stack-gap":x(t),"--stack-align":s,"--stack-justify":a}})),r=f((e,t)=>{const s=S("Stack",d,e),{classNames:a,className:c,style:l,styles:n,unstyled:i,vars:m,align:N,justify:R,gap:B,variant:p,...y}=s,g=j({name:"Stack",props:s,classes:o,className:c,style:l,classNames:a,styles:n,unstyled:i,vars:m,varsResolver:h});return u.jsx(v,{ref:t,...g("root"),variant:p,...y})});r.classes=o;r.displayName="@mantine/core/Stack";export{r as S};
