import{j as _}from"./jsx-runtime-D_zvdyIk.js";import{a as $}from"./chunk-QMGIS6GS-CBZUm-7V.js";import{j as B,h as N,m as d,i as R,B as S,o as z}from"./polymorphic-factory-EW0USS3V.js";function E(r){return $.Children.toArray(r).filter(Boolean)}var u={root:"m_4081bf90"};const O={preventGrowOverflow:!0,gap:"md",align:"center",justify:"flex-start",wrap:"wrap"},P=z((r,{grow:o,preventGrowOverflow:s,gap:t,align:e,justify:a,wrap:l},{childWidth:n})=>({root:{"--group-child-width":o&&s?n:void 0,"--group-gap":d(t),"--group-align":e,"--group-justify":a,"--group-wrap":l}})),m=B((r,o)=>{const s=N("Group",O,r),{classNames:t,className:e,style:a,styles:l,unstyled:n,children:f,gap:g,align:W,justify:b,wrap:A,grow:h,preventGrowOverflow:F,vars:y,variant:v,__size:w,mod:x,...G}=s,i=E(f),p=i.length,c=d(g??"md"),j={childWidth:`calc(${100/p}% - (${c} - ${c} / ${p}))`},C=R({name:"Group",props:s,stylesCtx:j,className:e,style:a,classes:u,classNames:t,styles:l,unstyled:n,vars:y,varsResolver:P});return _.jsx(S,{...C("root"),ref:o,variant:v,mod:[{grow:h},x],size:w,...G,children:i})});m.classes=u;m.displayName="@mantine/core/Group";export{m as G};
