import{a as o}from"./chunk-QMGIS6GS-CBZUm-7V.js";function u(n,e){if(typeof n=="function")return n(e);typeof n=="object"&&n!==null&&"current"in n&&(n.current=e)}function s(...n){const e=new Map;return a=>{if(n.forEach(t=>{const c=u(t,a);c&&e.set(t,c)}),e.size>0)return()=>{n.forEach(t=>{const c=e.get(t);c?c():u(t,null)}),e.clear()}}}function r(...n){return o.useCallback(s(...n),n)}export{u as a,r as u};
