import{j as z}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{r as $,j as x,h as y,i as S,B as T,o as w}from"./polymorphic-factory-EW0USS3V.js";const W=["h1","h2","h3","h4","h5","h6"],j=["xs","sm","md","lg","xl"];function H(e,i){const t=i!==void 0?i:`h${e}`;return W.includes(t)?{fontSize:`var(--mantine-${t}-font-size)`,fontWeight:`var(--mantine-${t}-font-weight)`,lineHeight:`var(--mantine-${t}-line-height)`}:j.includes(t)?{fontSize:`var(--mantine-font-size-${t})`,fontWeight:`var(--mantine-h${e}-font-weight)`,lineHeight:`var(--mantine-h${e}-line-height)`}:{fontSize:$(t),fontWeight:`var(--mantine-h${e}-font-weight)`,lineHeight:`var(--mantine-h${e}-line-height)`}}var r={root:"m_8a5d1357"};const b={order:1},N=w((e,{order:i,size:t,lineClamp:s,textWrap:o})=>{const n=H(i||1,t);return{root:{"--title-fw":n.fontWeight,"--title-lh":n.lineHeight,"--title-fz":n.fontSize,"--title-line-clamp":typeof s=="number"?s.toString():void 0,"--title-text-wrap":o}}}),l=x((e,i)=>{const t=y("Title",b,e),{classNames:s,className:o,style:n,styles:h,unstyled:m,order:a,vars:f,size:c,variant:g,lineClamp:u,textWrap:R,mod:p,...v}=t,d=S({name:"Title",props:t,classes:r,className:o,style:n,classNames:s,styles:h,unstyled:m,vars:f,varsResolver:N});return[1,2,3,4,5,6].includes(a)?z.jsx(T,{...d("root"),component:`h${a}`,variant:g,ref:i,mod:[{order:a,"data-line-clamp":typeof u=="number"},p],size:c,...v}):null});l.classes=r;l.displayName="@mantine/core/Title";export{l as T};
