import{j as d}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{j as _,h as m,i as x,o as G,B as y,r as L,q as P,v as T,s as I,p as U}from"./polymorphic-factory-EW0USS3V.js";import{U as q,T as D,L as E}from"./Loader-1VreoqJz.js";var l={root:"m_8d3f4000",icon:"m_8d3afb97",loader:"m_302b9fb1",group:"m_1a0f1b21",groupSection:"m_437b6484"};const z={orientation:"horizontal"},V=G((o,{borderWidth:n})=>({group:{"--ai-border-width":L(n)}})),j=_((o,n)=>{const r=m("ActionIconGroup",z,o),{className:t,style:a,classNames:e,styles:i,unstyled:s,orientation:p,vars:c,borderWidth:S,variant:v,mod:h,...g}=m("ActionIconGroup",z,o),u=x({name:"ActionIconGroup",props:r,classes:l,className:t,style:a,classNames:e,styles:i,unstyled:s,vars:c,varsResolver:V,rootSelector:"group"});return d.jsx(y,{...u("group"),ref:n,variant:v,mod:[{"data-orientation":p},h],role:"group",...g})});j.classes=l;j.displayName="@mantine/core/ActionIconGroup";const C={},W=G((o,{radius:n,color:r,gradient:t,variant:a,autoContrast:e,size:i})=>{const s=o.variantColorResolver({color:r||o.primaryColor,theme:o,gradient:t,variant:a||"filled",autoContrast:e});return{groupSection:{"--section-height":I(i,"section-height"),"--section-padding-x":I(i,"section-padding-x"),"--section-fz":T(i),"--section-radius":n===void 0?void 0:P(n),"--section-bg":r||a?s.background:void 0,"--section-color":s.color,"--section-bd":r||a?s.border:void 0}}}),R=_((o,n)=>{const r=m("ActionIconGroupSection",C,o),{className:t,style:a,classNames:e,styles:i,unstyled:s,vars:p,variant:c,gradient:S,radius:v,autoContrast:h,...g}=m("ActionIconGroupSection",C,o),u=x({name:"ActionIconGroupSection",props:r,classes:l,className:t,style:a,classNames:e,styles:i,unstyled:s,vars:p,varsResolver:W,rootSelector:"groupSection"});return d.jsx(y,{...u("groupSection"),ref:n,variant:c,...g})});R.classes=l;R.displayName="@mantine/core/ActionIconGroupSection";const H={},J=G((o,{size:n,radius:r,variant:t,gradient:a,color:e,autoContrast:i})=>{const s=o.variantColorResolver({color:e||o.primaryColor,theme:o,gradient:a,variant:t||"filled",autoContrast:i});return{root:{"--ai-size":I(n,"ai-size"),"--ai-radius":r===void 0?void 0:P(r),"--ai-bg":e||t?s.background:void 0,"--ai-hover":e||t?s.hover:void 0,"--ai-hover-color":e||t?s.hoverColor:void 0,"--ai-color":s.color,"--ai-bd":e||t?s.border:void 0}}}),b=U((o,n)=>{const r=m("ActionIcon",H,o),{className:t,unstyled:a,variant:e,classNames:i,styles:s,style:p,loading:c,loaderProps:S,size:v,color:h,radius:g,__staticSelector:u,gradient:K,vars:$,children:B,disabled:A,"data-disabled":N,autoContrast:M,mod:k,...w}=r,f=x({name:["ActionIcon",u],props:r,className:t,style:p,classes:l,classNames:i,styles:s,unstyled:a,vars:$,varsResolver:J});return d.jsxs(q,{...f("root",{active:!A&&!c&&!N}),...w,unstyled:a,variant:e,size:v,disabled:A||c,ref:n,mod:[{loading:c,disabled:A||N},k],children:[d.jsx(D,{mounted:!!c,transition:"slide-down",duration:150,children:F=>d.jsx(y,{component:"span",...f("loader",{style:F}),"aria-hidden":!0,children:d.jsx(E,{color:"var(--ai-color)",size:"calc(var(--ai-size) * 0.55)",...S})})}),d.jsx(y,{component:"span",mod:{loading:c},...f("icon"),children:B})]})});b.classes=l;b.displayName="@mantine/core/ActionIcon";b.Group=j;b.GroupSection=R;export{b as A};
