import{j as y}from"./jsx-runtime-D_zvdyIk.js";import"./chunk-QMGIS6GS-CBZUm-7V.js";import{p as P,h as w,i as x,B as R,o as f,z as g,q as j}from"./polymorphic-factory-EW0USS3V.js";var r={root:"m_1b7284a3"};const B={},N=f((o,{radius:s,shadow:a})=>({root:{"--paper-radius":s===void 0?void 0:j(s),"--paper-shadow":g(a)}})),e=P((o,s)=>{const a=w("Paper",B,o),{classNames:t,className:p,style:d,styles:i,unstyled:m,withBorder:c,vars:l,radius:S,shadow:b,variant:n,mod:h,...u}=a,v=x({name:"Paper",props:a,classes:r,className:p,style:d,classNames:t,styles:i,unstyled:m,vars:l,varsResolver:N});return y.jsx(R,{ref:s,mod:[{"data-with-border":c},h],...v("root"),variant:n,...u})});e.classes=r;e.displayName="@mantine/core/Paper";export{e as P};
