._value_1x01f_5{font-size:24px;font-weight:700;line-height:1}._diff_1x01f_11{line-height:1;display:flex;align-items:center}._icon_1x01f_17{color:var(--mantine-color-gray-4)}[data-mantine-color-scheme=dark] ._icon_1x01f_17{color:var(--mantine-color-dark-3)}._title_1x01f_21{font-weight:700;text-transform:uppercase}
