._user_1ofyj_1{display:block;width:100%;padding:var(--mantine-spacing-md);color:var(--mantine-color-black)}[data-mantine-color-scheme=dark] ._user_1ofyj_1{color:var(--mantine-color-dark-0)}@media (hover: hover){._user_1ofyj_1:hover{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._user_1ofyj_1:hover{background-color:var(--mantine-color-dark-8)}}@media (hover: none){._user_1ofyj_1:active{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._user_1ofyj_1:active{background-color:var(--mantine-color-dark-8)}}._root_wxlfk_1{position:relative;padding:var(--mantine-spacing-md);transition:border-color .15s ease}._root_wxlfk_1[data-checked]{border-color:var(--mantine-primary-color-filled)}@media (hover: hover){[data-mantine-color-scheme=light] ._root_wxlfk_1:hover{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._root_wxlfk_1:hover{background-color:var(--mantine-color-dark-6)}}@media (hover: none){[data-mantine-color-scheme=light] ._root_wxlfk_1:active{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._root_wxlfk_1:active{background-color:var(--mantine-color-dark-6)}}._label_wxlfk_21{font-family:var(--mantine-font-family-monospace);font-weight:500;font-size:var(--mantine-font-size-sm);line-height:1.3;color:var(--mantine-color-bright)}._description_wxlfk_29{margin-top:8px;color:var(--mantine-color-dimmed);font-size:var(--mantine-font-size-xs)}
