._navbar_9qhxk_1{background-color:var(--mantine-color-body);height:100vh;width:300px;padding:var(--mantine-spacing-md);padding-top:0;display:flex;flex-direction:column;border-right:1px solid var(--mantine-color-gray-3)}[data-mantine-color-scheme=dark] ._navbar_9qhxk_1{border-right:1px solid var(--mantine-color-dark-4)}._section_9qhxk_13{margin-left:calc(var(--mantine-spacing-md) * -1);margin-right:calc(var(--mantine-spacing-md) * -1);margin-bottom:var(--mantine-spacing-md)}._section_9qhxk_13:not(:last-of-type){border-bottom:1px solid var(--mantine-color-gray-3)}[data-mantine-color-scheme=dark] ._section_9qhxk_13:not(:last-of-type){border-bottom:1px solid var(--mantine-color-dark-4)}._searchCode_9qhxk_24{font-weight:700;font-size:10px;background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._searchCode_9qhxk_24{background-color:var(--mantine-color-dark-7)}._searchCode_9qhxk_24{border:1px solid var(--mantine-color-gray-2)}[data-mantine-color-scheme=dark] ._searchCode_9qhxk_24{border:1px solid var(--mantine-color-dark-7)}._mainLinks_9qhxk_35{padding-left:calc(var(--mantine-spacing-md) - var(--mantine-spacing-xs));padding-right:calc(var(--mantine-spacing-md) - var(--mantine-spacing-xs));padding-bottom:var(--mantine-spacing-md)}._mainLink_9qhxk_35{display:flex;align-items:center;width:100%;font-size:var(--mantine-font-size-xs);padding:8px var(--mantine-spacing-xs);border-radius:var(--mantine-radius-sm);font-weight:500;color:var(--mantine-color-gray-7)}[data-mantine-color-scheme=dark] ._mainLink_9qhxk_35{color:var(--mantine-color-dark-0)}._mainLink_9qhxk_35:hover{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._mainLink_9qhxk_35:hover{background-color:var(--mantine-color-dark-6)}._mainLink_9qhxk_35:hover{color:var(--mantine-color-gray-7)}[data-mantine-color-scheme=dark] ._mainLink_9qhxk_35:hover{color:var(--mantine-color-dark-0)}._mainLinkInner_9qhxk_63{display:flex;align-items:center;flex:1}._mainLinkIcon_9qhxk_69{margin-right:var(--mantine-spacing-sm);color:var(--mantine-color-gray-6)}[data-mantine-color-scheme=dark] ._mainLinkIcon_9qhxk_69{color:var(--mantine-color-dark-2)}._mainLinkBadge_9qhxk_74{padding:0;width:20px;height:20px;pointer-events:none}._collections_9qhxk_81{padding-left:calc(var(--mantine-spacing-md) - 6px);padding-right:calc(var(--mantine-spacing-md) - 6px);padding-bottom:var(--mantine-spacing-md)}._collectionsHeader_9qhxk_87{padding-left:calc(var(--mantine-spacing-md) + 2px);padding-right:var(--mantine-spacing-md);margin-bottom:5px}._collectionLink_9qhxk_93{display:block;padding:8px var(--mantine-spacing-xs);text-decoration:none;border-radius:var(--mantine-radius-sm);font-size:var(--mantine-font-size-xs);color:var(--mantine-color-gray-7)}[data-mantine-color-scheme=dark] ._collectionLink_9qhxk_93{color:var(--mantine-color-dark-0)}._collectionLink_9qhxk_93{line-height:1;font-weight:500}._collectionLink_9qhxk_93:hover{background-color:var(--mantine-color-gray-0)}[data-mantine-color-scheme=dark] ._collectionLink_9qhxk_93:hover{background-color:var(--mantine-color-dark-6)}._collectionLink_9qhxk_93:hover{color:var(--mantine-color-gray-7)}[data-mantine-color-scheme=dark] ._collectionLink_9qhxk_93:hover{color:var(--mantine-color-dark-0)}
