import{j as r}from"./jsx-runtime-D_zvdyIk.js";import{a as n,D as R}from"./chunk-QMGIS6GS-CBZUm-7V.js";import{p as I,h as S,i as j,o as _,r as B,q as z,s as E}from"./polymorphic-factory-EW0USS3V.js";import{U as P}from"./Loader-1VreoqJz.js";function A(e=null){const t=n.createContext(e);return[({children:a,value:i})=>r.jsx(t.Provider,{value:i,children:a}),()=>n.useContext(t)]}function N(e="mantine-"){return`${e}${Math.random().toString(36).slice(2,11)}`}const O=typeof document<"u"?n.useLayoutEffect:n.useEffect,U=R.useId||(()=>{});function $(){const e=U();return e?`mantine-${e.replace(/:/g,"")}`:""}function G(e){const t=$(),[s,o]=n.useState(t);return O(()=>{o(N())},[]),typeof e=="string"?e:typeof window>"u"?t:s}const m=n.forwardRef(({size:e="var(--cb-icon-size, 70%)",style:t,...s},o)=>r.jsx("svg",{viewBox:"0 0 15 15",fill:"none",xmlns:"http://www.w3.org/2000/svg",style:{...t,width:e,height:e},ref:o,...s,children:r.jsx("path",{d:"M11.7816 4.03157C12.0062 3.80702 12.0062 3.44295 11.7816 3.2184C11.5571 2.99385 11.193 2.99385 10.9685 3.2184L7.50005 6.68682L4.03164 3.2184C3.80708 2.99385 3.44301 2.99385 3.21846 3.2184C2.99391 3.44295 2.99391 3.80702 3.21846 4.03157L6.68688 7.49999L3.21846 10.9684C2.99391 11.193 2.99391 11.557 3.21846 11.7816C3.44301 12.0061 3.80708 12.0061 4.03164 11.7816L7.50005 8.31316L10.9685 11.7816C11.193 12.0061 11.5571 12.0061 11.7816 11.7816C12.0062 11.557 12.0062 11.193 11.7816 10.9684L8.31322 7.49999L11.7816 4.03157Z",fill:"currentColor",fillRule:"evenodd",clipRule:"evenodd"})}));m.displayName="@mantine/core/CloseIcon";var f={root:"m_86a44da5","root--subtle":"m_220c80f2"};const D={variant:"subtle"},M=_((e,{size:t,radius:s,iconSize:o})=>({root:{"--cb-size":E(t,"cb-size"),"--cb-radius":s===void 0?void 0:z(s),"--cb-icon-size":B(o)}})),p=I((e,t)=>{const s=S("CloseButton",D,e),{iconSize:o,children:a,vars:i,radius:q,className:C,classNames:v,style:x,styles:y,unstyled:d,"data-disabled":l,disabled:c,variant:u,icon:h,mod:b,__staticSelector:g,...w}=s,L=j({name:g||"CloseButton",props:s,className:C,style:x,classes:f,classNames:v,styles:y,unstyled:d,vars:i,varsResolver:M});return r.jsxs(P,{ref:t,...w,unstyled:d,variant:u,disabled:c,mod:[{disabled:c||l},b],...L("root",{variant:u,active:!c&&!l}),children:[h||r.jsx(m,{}),a]})});p.classes=f;p.displayName="@mantine/core/CloseButton";export{p as C,G as a,A as c,N as r,O as u};
