import"./chunk-QMGIS6GS-CBZUm-7V.js";import"./jsx-runtime-D_zvdyIk.js";import{h as I,x as O}from"./polymorphic-factory-EW0USS3V.js";function D(c,u,_){const r=I(c,u,_),{label:y,description:d,error:t,required:o,classNames:s,styles:p,className:m,unstyled:e,__staticSelector:i,__stylesApiProps:a,errorProps:w,labelProps:A,descriptionProps:h,wrapperProps:x,id:n,size:l,style:b,inputContainer:f,inputWrapperOrder:v,withAsterisk:N,variant:P,vars:W,mod:S,...k}=r,{styleProps:q,rest:z}=O(k),C={label:y,description:d,error:t,required:o,classNames:s,className:m,__staticSelector:i,__stylesApiProps:a||r,errorProps:w,labelProps:A,descriptionProps:h,unstyled:e,styles:p,size:l,style:b,inputContainer:f,inputWrapperOrder:v,withAsterisk:N,variant:P,id:n,mod:S,...x};return{...z,classNames:s,styles:p,unstyled:e,wrapperProps:{...C,...q},inputProps:{required:o,classNames:s,styles:p,unstyled:e,size:l,__staticSelector:i,__stylesApiProps:a||r,error:t,variant:P,id:n}}}export{D as u};
